# SDL::OpenGL::Model.pm
#
#	Parent for all 3D model objects
#
#	Copyright (C) 2002 David J. Goehrig

package SDL::OpenGL::Model;

use SDL::OpenGL;

1;

__END__;

=pod

=head1 NAME

SDL::OpenGL::Model

=head1 DESCRIPTION

This is just a stub for a future baseclass for OpenGL models.

=head1 AUTHOR

David J. Goehrig

=head1 SEE ALSO

L<perl> L<SDL::OpenGL>

=cut
